import 'package:fcs/domain/entities/discount.dart';
import 'package:fcs/domain/entities/payment_method.dart';
import 'package:fcs/domain/vo/message.dart';

abstract class CommonService {
  // Payment
  Future<void> createPaymentMethod(PaymentMethod paymentMethod);
  Future<void> updatePaymentMethod(PaymentMethod paymentMethod);
  Future<void> deletePayment(String id);

  // Messaging
  Future<void> sendMessage(Message message);
  Future<void> seenMessage(String ownerID, bool seenByOwner);

  // Payment
  Future<void> createDiscount(Discount discount);
  Future<void> updateDiscount(Discount discount);
  Future<void> deleteDiscount(String id);
}
